@@ -31,10 +31,13 @@ cclcda2.default <- function(       x,                   # dataframe containing t
 
   # if `grouping' vector not given, first data column is taken. 
   if (is.null(grouping)) {
-    grouping <- data[,1]
-    data <- data[,-1]
+    grouping <- x[,1]
+    x <- x[,-1]
   }
 
+  validate_manifest_data(x)
+  validate_grouping(grouping)
+
   varnames <- colnames(x)
   k <- max(grouping, na.rm=TRUE) # number of groups 
   d <- ncol(x)                   # number of variables 
@@ -295,5 +298,3 @@ print.cclcda2 <- function(x, ...)
 
 
 
-
-
